UpdateDriverPassengerModeStatus enum

Update driver passenger mode status enum

Inheritance
Available extensions

Values

success → const UpdateDriverPassengerModeStatus

Success, the data have been updated in the local database

invalidTransportationMode → const UpdateDriverPassengerModeStatus

Error, the trip was made with an alternative transport

invalidItineraryId → const UpdateDriverPassengerModeStatus

Error, the itinId is not valid

commentTooLong → const UpdateDriverPassengerModeStatus

Error, the comment is too long

failedToUpdateMode → const UpdateDriverPassengerModeStatus

An error occurred, for example when the user has no network

userNotConnected → const UpdateDriverPassengerModeStatus

An error occurred, the user is not yet connected

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<UpdateDriverPassengerModeStatus>
A constant List of the values in this enum, in order of their declaration.