DriveKitDriverData class
The main class of the plugin. This class provides methods to interact with the DriveKit DriverData SDK.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteTrip(
String itinId) → Future< bool> - Delete a trip
-
getRoute(
String itinId) → Future< GetRouteResponse?> - Get route
-
getTrip(
String itinId) → Future< GetTripResponse?> - Get trip by identider
-
getTripsOrderByDateAsc(
{SynchronizationType synchronizationType = SynchronizationType.defaultSync, List< TransportationMode> transportationModes = const [TransportationMode.unknown, TransportationMode.car, TransportationMode.moto, TransportationMode.truck]}) → Future<GetTripsResponse?> - Get trips ordered by date ascending
-
getTripsOrderByDateDesc(
{SynchronizationType synchronizationType = SynchronizationType.defaultSync, List< TransportationMode> transportationModes = const [TransportationMode.unknown, TransportationMode.car, TransportationMode.moto, TransportationMode.truck]}) → Future<GetTripsResponse?> - Get trips ordered by date descending
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateDriverPassengerMode(
String itinId, DriverPassengerMode mode, String comment) → Future< UpdateDriverPassengerModeStatus> - Declare a trip made as passenger or driver
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → DriveKitDriverData
-
unique instance of the DriveKitDriverData
no setter