Route class
Route Class
Constructors
-
Route({required List<
int?> ? callIndex, required List<int?> ? callTime, required String? itinId, required List<double?> ? latitude, required List<double?> ? longitude, required List<int?> ? screenLockedIndex, required List<int?> ? screenLockedTime, required List<int?> ? speedingIndex, required List<int?> ? speedingTime}) - Creates a Route instance
Properties
-
callIndex
→ List<
int?> ? -
call indexes array
final
-
callTime
→ List<
int?> ? -
call time array
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itinId → String?
-
trip identifier
final
-
latitude
→ List<
double?> ? -
latitude array
final
-
longitude
→ List<
double?> ? -
longitude array
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
screenLockedIndex
→ List<
int?> ? -
screen locked indexes array
final
-
screenLockedTime
→ List<
int?> ? -
screen locked time array
final
-
speedingIndex
→ List<
int?> ? -
speeding indexes array
final
-
speedingTime
→ List<
int?> ? -
speeding time array
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited