TransportationMode enum
Trip Transportation mode
Values
- unknown → const TransportationMode
-
Unknown
- car → const TransportationMode
-
Car Trip
- moto → const TransportationMode
-
Motorcycle Trip
- truck → const TransportationMode
-
Heavy-duty vehicle Trip
- bus → const TransportationMode
-
Bus Trip
- train → const TransportationMode
-
Rail trip
- boat → const TransportationMode
-
Boat trip
- bike → const TransportationMode
-
Bike trip
- flight → const TransportationMode
-
Plane Trip
- skiing → const TransportationMode
-
Ski Trip
- onFoot → const TransportationMode
-
On foot Trip
- idle → const TransportationMode
-
Idle
- other → const TransportationMode
-
Other
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TransportationMode> - A constant List of the values in this enum, in order of their declaration.