Trip class
Trip class
Constructors
-
Trip({required String? itinId, required String? startDate, required String? endDate, required String? departureAddress, required String? departureCity, required String? departurePostalCode, required String? departureState, required String? departureCountry, required String? arrivalAddress, required String? arrivalCity, required String? arrivalPostalCode, required String? arrivalState, required String? arrivalCountry, required String? vehicleId, required TripStatistics? tripStatistics, required EcoDriving? ecoDriving, required FuelEstimation? fuelEstimation, required Safety? safety, required AdvancedEcoDriving? advancedEcoDriving, required AdvancedFuelEstimation? advancedFuelEstimation, required AdvancedSafety? advancedSafety, required Pollutants? pollutants, required TireWear? tireWear, required BrakeWear? brakeWear, required DriverDistraction? driverDistraction, required Logbook? logbook, required OccupantInfo? occupantInfo, required List<
SafetyEvent> ? safetyEvents, required SpeedingStatistics? speedingStatistics, required EnergyEstimation? energyEstimation, required List<AdvancedEnergyEstimation> ? advancedEnergyEstimation, required Map<String, String> ? metaData, required int transportationMode, required bool unscored, required List<Call> ? calls, required List<SpeedLimitContext> ? speedLimitContexts}) - Creates a Trip instance
Properties
- advancedEcoDriving → AdvancedEcoDriving?
-
The advanced eco driving information
final
-
advancedEnergyEstimation
→ List<
AdvancedEnergyEstimation> ? -
The list of advanced energy estimations
final
- advancedFuelEstimation → AdvancedFuelEstimation?
-
The advanced fuel estimation information
final
- advancedSafety → AdvancedSafety?
-
The advanced safety information
final
- arrivalAddress → String?
-
The arrival full address
final
- arrivalCity → String?
-
The arrival city
final
- arrivalCountry → String?
-
The arrival country
final
- arrivalPostalCode → String?
-
The arrival postal code
final
- arrivalState → String?
-
The arrival state
final
- brakeWear → BrakeWear?
-
The brake wear information
final
-
calls
→ List<
Call> ? -
The list of calls
final
- departureAddress → String?
-
The departure full address
final
- departureCity → String?
-
The departure city
final
- departureCountry → String?
-
The departure country
final
- departurePostalCode → String?
-
The departure postal code
final
- departureState → String?
-
The departure state
final
- driverDistraction → DriverDistraction?
-
The driver distraction information
final
- ecoDriving → EcoDriving?
-
The eco driving information
final
- endDate → String?
-
The end date
final
- energyEstimation → EnergyEstimation?
-
The energy estimation information
final
- fuelEstimation → FuelEstimation?
-
The fuel estimation information
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itinId → String?
-
The itinerary ID
final
- logbook → Logbook?
-
The logbook information
final
-
metaData
→ Map<
String, String> ? -
The metadata
final
- occupantInfo → OccupantInfo?
-
The occupant role and passenger probability information
final
- pollutants → Pollutants?
-
The pollutants information
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- safety → Safety?
-
The safety information
final
-
safetyEvents
→ List<
SafetyEvent> ? -
The list of safety events
final
- speedingStatistics → SpeedingStatistics?
-
The speeding statistics
final
-
speedLimitContexts
→ List<
SpeedLimitContext> ? -
The list of speed limit contexts
final
- startDate → String?
-
The start date
final
- tireWear → TireWear?
-
The tire wear information
final
- transportationMode → int
-
The transportation mode
final
- tripStatistics → TripStatistics?
-
The itinerary statistics
final
- unscored → bool
-
The trip is scored or not
final
- vehicleId → String?
-
The vehicle ID
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited